<img src="./design/logo-combined.svg" alt="SQLEyes" title="SQLEyes logo" style="max-width:100%; width:100%">

---

![Tests](https://github.com/mCodingLLC/SlapThatLikeButton-TestingStarterProject/actions/workflows/tests.yml/badge.svg)

## About SQLEyes

Sqleyes is a CLI tool for analyzing simple, raw SQL queries for common sql anti-patterns.

### Repository

This repository contains the main SQLEyes package as well as the unit tests

> This project was developed as a master's graduation project at Eindhoven University of Technology
> Code boilerplate and best practices from [best-practice-and-impact](https://github.com/best-practice-and-impact/example-package-python)
